pub struct Multiserver<P, T: Transport = <P as HasTransport>::Transport> { /* private fields */ }Expand description
A server that handles incoming messages from multiple transports.
Multiservers are useful when you want to use a single server handler to handle messages from multiple served transports. They coalesce all of the incoming requests into a single conceptual stream, and invoke the handler on each one serially.
Multiserver is a handle that can forward server ends to its
MultiserverDispatcher. The dispatcher is what handles each of the
incoming messages. Call multiserver to create a handle and dispatcher
pair.
Example
ⓘ
let (server, dispatcher) = multiserver();
spawn(dispatcher.run(my_handler));
while let Some(server_end) = incoming.next().await {
server.forward(server_end);
}Implementations
Sourceimpl<P, T: Transport> Multiserver<P, T>
impl<P, T: Transport> Multiserver<P, T>