pub struct MultiserverDispatcher<P, T: Transport = <P as HasTransport>::Transport> { /* private fields */ }Expand description
A dispatcher for a multiserver.
A multiserver runs servers for multiple transmports using the same handler.
See Multiserver for usage details.
Implementations
Sourceimpl<P, T: Transport> MultiserverDispatcher<P, T>
impl<P, T: Transport> MultiserverDispatcher<P, T>
Sourcepub async fn run<H>(self, handler: H)where
P: DispatchServerMessage<H, T>,
H: Send,
pub async fn run<H>(self, handler: H)where
P: DispatchServerMessage<H, T>,
H: Send,
Runs the multiserver with the provided handler.
The handler will be called with messages from multiple transports.
Sourcepub async fn run_local<H>(self, handler: H)where
P: DispatchLocalServerMessage<H, T>,
pub async fn run_local<H>(self, handler: H)where
P: DispatchLocalServerMessage<H, T>,
Runs the multiserver with the provided local handler.
The handler will be called with messages from multiple transports.